# coding: utf-8

occurrences = {
    "02": "ENTRADA CONFIRMADA (COM POSSIBILIDADE DE MENSAGEM – NOTA 23 – TABELA 8)",
    "03": "ENTRADA REJEITADA (NOTA 23 - TABELA 1)",
    "04": "ALTERAÇÃO DE DADOS – NOVA ENTRADA OU ALTERAÇÃO/EXCLUSÃOADOS ACATADA",
    "05": "ALTERAÇÃO DE DADOS – BAIXA",
    "06": "LIQUIDAÇÃO NORMAL",
    "08": "LIQUIDAÇÃO EM CARTÓRIO",
    "09": "BAIXA SIMPLES",
    "10": "BAIXA POR TER SIDO LIQUIDADO",
    "11": "EM SER (SÓ NO RETORNO MENSAL)",
    "12": "ABATIMENTO CONCEDIDO",
    "13": "ABATIMENTO CANCELADO",
    "14": "VENCIMENTO ALTERADO",
    "15": "BAIXAS REJEITADAS (NOTA 23 - TABELA 4)",
    "16": "INSTRUÇÕES REJEITADAS (NOTA 23 – TABELA 3)",
    "17": "ALTERAÇÃO/EXCLUSÃO DE DADOS REJEITADA (NOTA 23 - TABELA 2)",
    "18": "COBRANÇA CONTRATUAL – INSTRUÇÕES/ALTERAÇÕES REJEITADAS/PENDENTES (NOTA 23 - TABELA 5)",
    "19": "CONFIRMAÇÃO RECEBIMENTO DE INSTRUÇÃO DE PROTESTO",
    "20": "CONFIRMAÇÃO RECEBIMENTO DE INSTRUÇÃO DE SUSTAÇÃO DE PROTESTO /TARIFA",
    "21": "CONFIRMAÇÃO RECEBIMENTO DE INSTRUÇÃO DE NÃO PROTESTAR",
    "23": "PROTESTO ENVIADO A CARTÓRIO/TARIFA",
    "24": "INSTRUÇÃO DE PROTESTO SUSTADA (NOTA 23 - TABELA 7)",
    "25": "ALEGAÇÕES DO PAGADOR (NOTA 23 - TABELA 6)",
    "26": "TARIFA DE AVISO DE COBRANÇA",
    "27": "TARIFA DE EXTRATO POSIÇÃO (B40X)",
    "28": "TARIFA DE RELAÇÃO DAS LIQUIDAÇÕES",
    "29": "TARIFA DE MANUTENÇÃO DE TÍTULOS VENCIDOS",
    "30": "DÉBITO MENSAL DE TARIFAS (PARA ENTRADAS E BAIXAS)",
    "32": "BAIXA POR TER SIDO PROTESTADO",
    "33": "CUSTAS DE PROTESTO",
    "34": "CUSTAS DE SUSTAÇÃO",
    "35": "CUSTAS DE CARTÓRIO DISTRIBUIDOR",
    "36": "CUSTAS DE EDITAL",
    "37": "TARIFA DE EMISSÃO DE BOLETO/TARIFA DE ENVIO DE DUPLICATA",
    "38": "TARIFA DE INSTRUÇÃO",
    "39": "TARIFA DE OCORRÊNCIAS",
    "40": "TARIFA MENSAL DE EMISSÃO DE BOLETO/TARIFA MENSAL DE ENVIO DE DUPLICATA",
    "41": "DÉBITO MENSAL DE TARIFAS – EXTRATO DE POSIÇÃO (B4EP/B4OX)",
    "42": "DÉBITO MENSAL DE TARIFAS – OUTRAS INSTRUÇÕES",
    "43": "DÉBITO MENSAL DE TARIFAS – MANUTENÇÃO DE TÍTULOS VENCIDOS",
    "44": "DÉBITO MENSAL DE TARIFAS – OUTRAS OCORRÊNCIAS",
    "45": "DÉBITO MENSAL DE TARIFAS – PROTESTO",
    "46": "DÉBITO MENSAL DE TARIFAS – SUSTAÇÃO DE PROTESTO",
    "47": "BAIXA COM TRANSFERÊNCIA PARA DESCONTO",
    "48": "CUSTAS DE SUSTAÇÃO JUDICIAL",
    "51": "TARIFA MENSAL REFERENTE A ENTRADAS BANCOS CORRESPONDENTES NA CARTEIRA",
    "52": "TARIFA MENSAL BAIXAS NA CARTEIRA",
    "53": "TARIFA MENSAL BAIXAS EM BANCOS CORRESPONDENTES NA CARTEIRA",
    "54": "TARIFA MENSAL DE LIQUIDAÇÕES NA CARTEIRA",
    "55": "TARIFA MENSAL DE LIQUIDAÇÕES EM BANCOS CORRESPONDENTES NA CARTEIRA",
    "56": "CUSTAS DE IRREGULARIDADE",
    "57": "INSTRUÇÃO CANCELADA (NOTA 23 – TABELA 8)",
    "60": "ENTRADA REJEITADA CARNÊ (NOTA 20 – TABELA 1)",
    "61": "TARIFA EMISSÃO AVISO DE MOVIMENTAÇÃO DE TÍTULOS (2154)",
    "62": "DÉBITO MENSAL DE TARIFA – AVISO DE MOVIMENTAÇÃO DE TÍTULOS (2154)",
    "63": "TÍTULO SUSTADO JUDICIALMENTE",
    "74": "INSTRUÇÃO DE NEGATIVAÇÃO EXPRESSA REJEITADA (NOTA 25 – TABELA 3)",
    "75": "CONFIRMA O RECEBIMENTO DE INSTRUÇÃO DE ENTRADA EM NEGATIVAÇÃO EXPRESSA",
    "77": "CONFIRMA O RECEBIMENTO DE INSTRUÇÃO DE EXCLUSÃO DE ENTRADA EM NEGATIVAÇÃO EXPRESSA",
    "78": "CONFIRMA O RECEBIMENTO DE INSTRUÇÃO DE CANCELAMENTO DA NEGATIVAÇÃO EXPRESSA",
    "79": "NEGATIVAÇÃO EXPRESSA INFORMACIONAL (NOTA 25 – TABELA 12)",
    "80": "CONFIRMAÇÃO DE ENTRADA EM NEGATIVAÇÃO EXPRESSA – TARIFA",
    "82": "CONFIRMAÇÃO O CANCELAMENTO DE NEGATIVAÇÃO EXPRESSA - TARIFA",
    "83": "CONFIRMAÇÃO DA EXCLUSÃO/CANCELAMENTO DA NEGATIVAÇÃO EXPRESSA POR LIQUIDAÇÃO - TARIFA",
    "85": "TARIFA POR BOLETO (ATÉ 03 ENVIOS) COBRANÇA ATIVA ELETRÔNICA",
    "86": "TARIFA EMAIL COBRANÇA ATIVA ELETRÔNICA",
    "87": "TARIFA SMS COBRANÇA ATIVA ELETRÔNICA",
    "88": "TARIFA MENSAL POR BOLETO (ATÉ 03 ENVIOS) COBRANÇA ATIVA ELETRÔNICA",
    "89": "TARIFA MENSAL EMAIL COBRANÇA ATIVA ELETRÔNICA",
    "90": "TARIFA MENSAL SMS COBRANÇA ATIVA ELETRÔNICA",
    "91": "TARIFA MENSAL DE EXCLUSÃO DE ENTRADA EM NEGATIVAÇÃO EXPRESSA",
    "92": "TARIFA MENSAL DE CANCELAMENTO DE NEGATIVAÇÃO EXPRESSA",
    "93": "TARIFA MENSAL DE EXCLUSÃO/CANCELAMENTO DE NEGATIVAÇÃO EXPRESSA POR LIQUIDAÇÃO",
    "94": "CONFIRMA RECEBIMENTO DE INSTRUÇÃO DE NÃO NEGATIVAR",
}